% ECE695 Power Electronics Converters and Systems
% Homework 1, Problem 1
%
% A simple simulation of a dc/dc converter solved with
% Runga-Kutta simulation algorithm
%
% Written by S.D. Sudhoff 
%   School of Electrical and Computer Engineering
%   1285 Electrical Engineering Building
%   West Lafayette, IN 47907-1285
%   Phone: 765-494-3246
%   Fax: 765-494-0676
%   E-mail: sudhoff@ecn.purdue.edu

% model parameters
P.L=5e-3;              % Inductor inductance (H)
P.rL=0.1;              % Inductor resistance (Ohms)
P.C=100e-6;            % Capacitor capacitance (F)
P.R=10.0;              % Load resistance (Ohms)
P.vin=300;             % Input voltage (V)
P.K=1e-3;              % Controller gain
P.tau=2e-3;            % Controller time constant
P.vref0=300;           % Initial reference voltage
P.vref1=600;           % Final reference voltage
P.tref=0.1;            % Time to switch reference voltage

% time values where we want the answer
tvals=linspace(0,0.2,2000);

% initial condition 
xic=[0 0 0];

% maximum time step
maxt=1e-4;

% peform the simulation
[t,x]=odefsrk(@regdcdc,tvals,xic,P,maxt);

% grab the waveforms
il=x(:,1);
vout=x(:,2);

% get the other waveforms
px=nan(3,length(t));
vls=nan(length(t));
ius=nan(length(t));
d=nan(length(t));
for ti=1:length(t),
   [px,vls,ius,iout,d(ti)]=regdcdc(t(ti),x(ti,:),P);
end

% plot the current
figure(1)
plot(tvals,il)
xlabel('t, s');
ylabel('i_L, A');
axis([0 0.2 0 200]);
grid on;
title('Fast Average Inductor Current');

% plot the voltage
figure(2)
plot(tvals,vout)
xlabel('t, s');
ylabel('v_{out}, A');
title('Fast Average Output Voltage');
grid on;
axis([0 0.2 0 1000]);

% plot the voltage
figure(3)
plot(tvals,d)
xlabel('t, s');
ylabel('d');
title('Duty Cycle');
grid on;
axis([0 0.2 0 1]);